# cabal2spec-0.25
# https://fedoraproject.org/wiki/Packaging:Haskell
# https://fedoraproject.org/wiki/PackagingDrafts/Haskell

%global pkg_name Agda

# common part of summary for all the subpackages
%global common_summary Agda dependently type programming language library

# main description used for all the subpackages
%global common_description Agda is a dependently typed functional programming language: it has\
inductive families, which are similar to Haskell's GADTs, but they can\
be indexed by values and not just types. It also has parameterized\
modules, mixfix operators, Unicode characters, and an interactive\
Emacs interface (the type checker can assist in the development of your code).\
\
Agda is also a proof assistant: It is an interactive system for writing and\
checking proofs. Agda is based on intuitionistic type theory,\
a foundational system for constructive mathematics developed by\
the Swedish logician Per Martin-Löf. It has many similarities with other\
proof assistants based on dependent types, such as Coq, Epigram and NuPRL.

Name:           ghc-%{pkg_name}
Version:        2.3.0.1
Release:        2%{?dist}
Summary:        Dependently typed functional programming language

Group:          Development/Languages
License:        MIT and BSD
# BEGIN cabal2spec
URL:            http://hackage.haskell.org/package/%{pkg_name}
Source0:        http://hackage.haskell.org/packages/archive/%{pkg_name}/%{version}/%{pkg_name}-%{version}.tar.gz
ExclusiveArch:  %{ghc_arches_with_ghci}
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros %{!?without_hscolour:hscolour}
# END cabal2spec
Source1:        agda-mode-init.el
BuildRequires:  ghc-binary-prof
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-hashtables-prof
BuildRequires:  ghc-haskeline-prof
BuildRequires:  ghc-haskell-src-exts-prof
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-pretty-prof
BuildRequires:  ghc-process-prof
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-syb-prof
BuildRequires:  ghc-xhtml-prof
BuildRequires:  ghc-zlib-prof
BuildRequires:  happy, alex
BuildRequires:  emacs-haskell-mode

%description
%{common_description}

For Emacs mode install emacs-agda.

If you want to use the command-line program (agda),
then you should also install Agda-executable.


%package -n emacs-agda
Summary:        Emacs mode for the Agda language
Group:          Applications/Editors
License:        MIT
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Requires:       emacs-haskell-mode
Requires:       emacs(bin) >= %{_emacs_version}

%description -n emacs-agda
%{common_description}

This is the interactive Emacs mode for Agda.

%package -n emacs-agda-el
Summary:        Elisp source files for Agda emacs mode
Group:          Applications/Editors
License:        MIT
Requires:       emacs-agda = %{version}-%{release}

%description -n emacs-agda-el
%{common_description}

This provides the Emacs Lisp source files for the Agda interactive mode.


%prep
%setup -q -n %{pkg_name}-%{version}


%build
%ghc_lib_build

%global elisp_files eri.el agda-input.el annotation.el agda2-highlight.el agda2-abbrevs.el agda2-mode.el agda2.el

cd src/data/emacs-mode
for i in %elisp_files; do
  %{_emacs_bytecompile} $i
done
cd -


%install
%ghc_lib_install

mkdir -p %{buildroot}%{_emacs_sitelispdir}/agda
for i in src/data/emacs-mode/*; do
  install -p -m 0644 $i %{buildroot}%{_emacs_sitelispdir}/agda
done

mkdir -p %{buildroot}%{_emacs_sitestartdir}
install -p -m 0644 %SOURCE1 %{buildroot}%{_emacs_sitestartdir}

rm %{buildroot}%{_bindir}/agda-mode
rm -r %{buildroot}%{_datadir}/%{pkg_name}-%{version}/EpicInclude
rm -r %{buildroot}%{_datadir}/%{pkg_name}-%{version}/emacs-mode

echo %{_datadir}/%{pkg_name}-%{version}/Agda.css >> ghc-%{pkg_name}.files


# devel subpackage
%ghc_devel_package

%ghc_devel_description


%ghc_devel_post_postun


%ghc_files LICENSE
%doc doc/release-notes


%files -n emacs-agda
%defattr(-,root,root,-)
%doc README
%dir %{_emacs_sitelispdir}/agda
%{_emacs_sitelispdir}/agda/*.elc
%{_emacs_sitestartdir}/*.el


%files -n emacs-agda-el
%defattr(-,root,root,-)
%{_emacs_sitelispdir}/agda/*.el


%changelog
* Thu May 31 2012 Jens Petersen <petersen@redhat.com> - 2.3.0.1-2
- library license is also BSD (#710031)
- move release notes to devel subpackage

* Tue Apr 10 2012 Jens Petersen <petersen@redhat.com> - 2.3.0.1-1
- update to 2.3.0.1 for ghc-7.4.1

* Tue Feb 14 2012 Jens Petersen <petersen@redhat.com> - 2.3.0-1
- update to 2.3.0
- update to cabal2spec-0.25
- new depends on hashtables

* Fri Jun  3 2011 Jens Petersen <petersen@redhat.com> - 2.2.10-2
- also BR alex, happy, and emacs-haskell-mode

* Thu Jun  2 2011 Jens Petersen <petersen@redhat.com> - 2.2.10-1
- MIT license
- add deps and description
- emacs mode subpackages

* Thu Jun  2 2011 Fedora Haskell SIG <haskell-devel@lists.fedoraproject.org> - 2.2.10-0
- initial packaging for Fedora automatically generated by cabal2spec-0.23
